style "panelbuttons" = "default"
{


 
 xthickness            			= 2
  ythickness            			= 0

#	GtkWidget::focus_padding = 2

	engine "pixmap" {
      
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= NORMAL
			file            						= "Panel/panelbutton1.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}
		
image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= PRELIGHT
			file            						= "Panel/panelbutton2.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}

		image
		{
			function        			= BOX
			recolorable     		= TRUE
			shadow							= OUT
			state										= PRELIGHT
			file            						= "Panel/panelbutton1.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
			#overlay_file   			= "panelbutton2.png"
			#overlay_border	= { 4, 4, 4, 4 }
			#overlay_stretch	= TRUE
		}
		
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			shadow							= IN
			state										= PRELIGHT
			file            						= "Panel/panelbutton3.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
			#overlay_file     		= "panelbutton2.png"
			#overlay_border	= { 4, 4, 4, 4 }
			#overlay_stretch	= TRUE
		}
		
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= ACTIVE
			file            						= "Panel/panelbutton3.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}  
image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= INSENSITIVE
			file            						= "Panel/panelbutton2.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}  

	}

}
widget_class "*Panel*GtkToggleButton" style "panelbuttons"
widget_class "*Panel*GtkButton" style "panelbuttons"

#################### PANEL BACKGROUND #########################xx

style "panelbg"
{
  xthickness            			= 0
  ythickness            			= 0
 bg_pixmap[NORMAL]					= "Panel/panel-bg.png"
#bg_pixmap[SELECTED]					= "Panel/panel-bg.png"
#bg_pixmap[INSENSITIVE]					= "Panel/panel-bg.png"
#bg_pixmap[PRELIGHT]					= "Panel/panel-bg.png"
 


}
class "*Panel*" style "panelbg"
class "*notif*" style "panelbg"
class "*Notif*" style "panelbg"
class "*Tray*" style "panelbg"
class "*tray*" style "panelbg"
