######################## MENU ################################x

style "menu"			= "default"
{

#bg_pixmap[NORMAL]       = "Menus/menu-overlay.png"
	xthickness = 0
	ythickness = 0
  	
 	 fg[PRELIGHT]  = "#000000"


  engine "pixmap"
  {
    image
    {
      function			= BOX
     recolorable    		= TRUE
      detail				= "menu"
      file				= "Menus/menu.gif"
      border			= { 0, 0, 0, 0 }
      stretch			= FALSE

    }
image
    {
      function		= HLINE
      recolorable     = TRUE
      file			= "Menus/menuline.png"
      border		= { 0, 0, 0, 0 }
      stretch		= TRUE
    }
  }
}

