#######################################################################

style "toolbarbuttons" = "default"
{
  xthickness            			= 0
  ythickness            			= 0

	GtkWidget::focus_padding = 0
 bg_pixmap[NORMAL]					= "Toolbar/toolbar-bg.png"

	engine "pixmap" {
      
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= NORMAL
			file            						= "Toolbar/toolbutton_normal.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}
		
image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= PRELIGHT
			file            						= "Toolbar/toolbutton_prelight.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}

		image
		{
			function        			= BOX
			recolorable     		= TRUE
			shadow							= OUT
			state										= PRELIGHT
			file            						= "Toolbar/toolbutton_prelight.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
			
		}
		
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			shadow							= IN
			state										= PRELIGHT
			file            						= "Toolbar/toolbutton_prelight.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
			
		}
		
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= ACTIVE
			file            						= "Toolbar/toolbutton_togle.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}  
image
		{
			function        			= BOX
			recolorable     		= TRUE
			state										= INSENSITIVE
			file            						= "Toolbar/toolbutton_normal.png"
			border          			= { 4, 4, 4, 4 }
			stretch         				= TRUE
		}  

	}

}
widget_class "*Toolbar*GtkToggleButton" style "toolbarbuttons"
widget_class "*Toolbar*GtkButton" style "toolbarbuttons"


####################################################






#######################################################################

####################################################



style "toolbar" = "default"
{
  xthickness            			= 0
  ythickness            			= 1
 
 engine "pixmap"
	{
		image
		{
			function	= BOX
			file		= "Toolbar/toolbar-bg.png"
			border	= { 3, 3, 3, 3 }
			stretch	= TRUE
    		}
 	}


}
class "*GtkToolbar*" style "toolbar"
class "GtkToolbar" style "toolbar"
